Position

Trait Position 

pub trait Position: Default + Serialize {
    // Required method
    fn new(ref_seq: String, pos: u32) -> Self;
}
A serializable object meant to hold all information about a position.

Required Methods

fn new(ref_seq: String, pos: u32) -> Self

Create a new position with all other values zeroed

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors